<?php
namespace Ep\Core;

use Psr\Container\ContainerInterface;
use Zend\ConfigAggregator\ConfigAggregator;
use Zend\ConfigAggregator\PhpFileProvider;
use Zend\ServiceManager\ServiceManager;

/**
 * Class ServiceManagerFactory
 *
 * @package Ep\Core
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ServiceManagerFactory
{
    public function __invoke()
    {
        $configProviders = apply_filters('ep/config/providers', [
            new PhpFileProvider(__DIR__ . '/../../../../../config/config.php'),
            new PhpFileProvider(__DIR__ . '/../../config/module.php'),

            \Zend\Filter\ConfigProvider::class,

            \Ep\WordPress\ConfigProvider::class,
            \Ep\WooCommerce\ConfigProvider::class,
        ]);

        $aggregator = new ConfigAggregator($configProviders);

        $config = $aggregator->getMergedConfig();

        $dependencies = apply_filters('ep/config/dependencies', $config['dependencies'] ?? []);
        $services = new ServiceManager($dependencies);

        $services->setService('config', $config);
        $services->setService('configProviders', $configProviders);
        $services->setService(ContainerInterface::class, $services);

        return $services;
    }
}