<?php
namespace Ep\WooCommerce;

use Ep\Gath\WordPress\ProductProvider;
use Ep\WordPress\Service\AbstractWordPressService;

/**
 * Class CartService
 *
 * @package Ep\WooCommerce
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class CartService extends AbstractWordPressService
{
	/** @var ProductProvider */
	protected $products;

	/**
	 * @return ProductProvider|mixed
	 */
	protected function getProductProvider()
	{
		if (null === $this->products) {
			$this->products = $this->services->get('GathProductProvider');
		}

		return $this->products;
	}

	protected function getProduct($productId)
	{
		$provider = $this->getProductProvider();
		return $provider->getProduct($productId);
	}

	public function attach(): void
	{
		add_action('wp_ajax_cart_import_csv', [$this, 'importCsv']);
		add_action('wp_ajax_nopriv_cart_import_csv', [$this, 'importCsv']);
	}

	public function importCsv()
	{
		if (0 !== $_FILES['csv']['error']) {
			wp_send_json([
				'success' => false,
				'message' => __('An error occurred while uploading the file!', 'ep-webshop'),
			]);
		}

		if (!in_array($_FILES['csv']['type'], ['text/csv', 'application/vnd.ms-excel'])) {
			wp_send_json([
				'success' => false,
				'message' => __('Invalid file type! Must be `text/csv`.', 'ep-webshop'),
			]);
		}

		$csv = file_get_contents($_FILES['csv']['tmp_name']);
		$lines = explode("\n", $csv);

		try {
			foreach ($lines as $line) {
				$line = explode(',', trim($line));
				$sku = $line[0];
				$quantity = intval($line[1]);

				if (!$quantity === 0) {
					continue;
				}

				$productId = wc_get_product_id_by_sku($sku);
				WC()->cart->add_to_cart($productId, $quantity);
			}
		} catch (\Exception $e) {
			wp_send_json([
				'success' => false,
				'message' => $e->getMessage(),
			]);
		}

		wp_send_json([
			'success' => true,
		]);
	}
}