<?php
namespace Ep\WordPress;

use Ep\Form\FormAbstractServiceFactory;
use Ep\WordPress\Settings\SettingsProviderInterface;
use Zend\ServiceManager\AbstractFactory\ReflectionBasedAbstractFactory;
use Zend\Stdlib\ArrayUtils;

/**
 * Konfiguracija WordPress komponenti
 *
 * @package Ep\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ConfigProvider implements SettingsProviderInterface
{
	public function __invoke()
	{
		$services = [
			'WordPressI18n',
			'WordPressMetadata',
			'FormcraftFileDownload',
		];

		$webshopConfig = $this->getDefaults()['ep_webshop'];

		if (function_exists('get_option')) {
			$webshopConfig = ArrayUtils::merge($webshopConfig, get_option('ep_webshop', []));
		}

		return [
			'dependencies' => $this->getDependencyConfig(),
			'webshop' => $webshopConfig,

			'wordpress' => [
				'services' => $services,

				'admin_services' => [
					'WordPressSettings',
				],
			],
		];
	}

	/**
	 * Vraća konfiguraciju za ServiceManager
	 *
	 * @return array
	 */
	public function getDependencyConfig()
	{
		return [
		    'abstract_factories' => [
		        FormAbstractServiceFactory::class,
            ],

			'aliases' => [
				'WordPress' => WordPressManager::class,
				'WordPressI18n' => Service\I18nService::class,
				'WordPressMetadata' => Service\MetadataService::class,
				'WordPressSettings' => Settings\SettingsService::class,
				'FormcraftFileDownload' => Formcraft\FileDownloadAddon::class,
			],
			'factories' => [
				WordPressManager::class         => WordPressManagerFactory::class,
                Service\I18nService::class => ReflectionBasedAbstractFactory::class,
				Service\MetadataService::class  => Service\MetadataServiceFactory::class,
				Settings\SettingsService::class => Settings\SettingsServiceFactory::class,
                Formcraft\FileDownloadAddon::class => ReflectionBasedAbstractFactory::class,
			],
		];
	}

	/**
	 * Vraća zadane postavke koje provider pruža.
	 *
	 * @return array
	 */
	public function getDefaults()
	{
		return [
			'ep_webshop' => [
				'type' => 'retail',
				'enable_cart_import_csv' => '0',
				'login_for_prices' => '0',
				'login_for_prices_text' => '',
                'register_password_hint' => $hint = __('Hint: The password should be at least twelve characters long. To make it stronger, use upper and lower case letters, numbers, and symbols like ! " ? $ % ^ &amp; ).'),
			],
		];
	}

	/**
	 * Vraća forme za postavke.
	 *
	 * @return array
	 */
	public function getForms()
	{
		return [
			'ep_webshop' => 'settings-webshop',
		];
	}

	/**
	 * Vraća tabove u control panelu koje ovaj provider definira.
	 *
	 * @return array
	 */
	public function getTabs()
	{
		return [[
			'id' => 'general',
			'title' => 'Općenito',
			'priority' => 10,
			'optionKeys' => [
				'ep_webshop',
			],
		]];
	}
}