<?php
namespace Ep\WordPress\Service;

use WP_Post;

/**
 * Objekti koji implementiraju ovo sučelje pružaju metapodatke za postove.
 *
 * Proizvodi su vrsta posta tako da ovime možemo injectati podatke iz Gatha
 * u proizvode.
 *
 * @package Ep\WordPress\Service
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
interface MetadataProviderInterface
{
	/**
	 * Omogućava providerima da preloadaju metapodatke za set postova.
	 *
	 * @param WP_Post[]|int[] $posts
	 *
	 * @return void
	 */
	public function preloadMetadata(array $posts): void;

	/**
	 * Vraća true ako ovaj provider može vratiti metapodatak s datim ključem.
	 *
	 * @param string $metaKey
	 *
	 * @return bool
	 */
	public function hasMetadata(string $metaKey): bool;

	/**
	 * Vraća vrijednost metapodatka iz nekog drugog izvora, ovisno o implementaciji.
	 *
	 * @param int $postId
	 * @param string $metaKey
	 * @param mixed|null $metaValue
	 *
	 * @return mixed
	 */
	public function getMetadata(int $postId, string $metaKey, $metaValue = null);
}