<?php
namespace Ep\WordPress\Settings;

use Interop\Container\ContainerInterface;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class SettingsServiceFactory
 *
 * @package Ep\WordPress\Settings
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class SettingsServiceFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return object
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		$providers = $container->get('configProviders');
		$settings = new SettingsService($container);

		foreach ($providers as $provider) {
			if (is_string($provider) && class_exists($provider)) {
				$provider = new $provider();

				if ($provider instanceof SettingsProviderInterface) {
					$settings->addProvider($provider);
				}
			}
		}

		return $settings;
	}
}